package LL;

use strict;
use warnings;
use base qw(Date::Holidays::Abstract);

sub holidays {}

sub is_holiday {}

1;

